<?php

/**
 * @file
 * Admin include file.
 */

/**
 * Displays the form for the standard settings tab.
 *
 * @return
 *   array A structured array for use with Forms API.
 */
function tutorial_admin_settings() {
  $tutorial = tutorial_include_api_class();
  if(!$tutorial) {
    return ''; 
  }
  $ret = $tutorial->getAPICredits();
  $account = 1;
  if(!$ret->credits_per_month) {
    drupal_set_message(t('You are unable to log in to tutorial. Please enter a valid tutorial API username and password.'), 'error');
    $account = 0;
  }
//dsm($ret);
  
  $form['tutorial_username'] = array(
    '#type' => 'textfield',
    '#title' => t('tutorial API username'), 
    '#description' => t(''),
    '#default_value' => variable_get('tutorial_username', ''), 
    '#description' => t('In order to enable the API tools you will need a tutorial account login (username & password). !tutorial_link.',
      array(
        '!tutorial_link' => l(t('Get your API account here'), tutorial_LINK_API_ACCOUNT, array('attributes' => array('target', 'tutorial'))),
      )
    )  
  );
  $form['tutorial_password'] = array(
    '#type' => 'password',
    '#title' => t('tutorial API password'), 
    '#description' => t(''),
    '#default_value' => variable_get('tutorial_password', ''), 
  );
  
  $form['tutorial_free_embed_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Free widgets embed id'), 
    '#description' => t(''),
    '#default_value' => variable_get('tutorial_free_embed_id', ''), 
    '#description' => t('In order to enable the free javascript tools you will need a tutorial widget embed id. The embed id is a part of the widget embed code that you can generate on the tutorial site. Enter in the field above the 20 character value following "embed_id=" in the widget embed code. !tutorial_link.',
      array(
        '!tutorial_link' => l(t('Get your embed code here'), tutorial_LINK_WIDGET_GENERATOR, array('attributes' => array('target', 'tutorial'))),
      )
    )    
  );

  $form['tutorial_adult_filter_default'] = array(
    '#type' => 'checkbox',
    '#title' => t('Adult keyword filter default'),
    '#return_value' => 'on',
    '#default_value' => variable_get('tutorial_adult_filter_default', TRUE),
    '#description' => t('Set the default value adult filter for tutorial report values.'),
  );
  
  $form['tutorial_cache_time'] = array(
    '#type' => 'textfield',
    '#title' => t('Cache time'), 
    '#description' => t('API results are cached. Use this value to set in seconds the time before checking if the cache data is out of date.'),
    '#default_value' => variable_get('tutorial_cache_time', 604800), 
  );

  if (!$account) {
    return system_settings_form($form);
  }
  $form['tutorial_account_status'] = array(
    '#type' => 'markup',
    '#value' => '<h3>' . t('Account Status') . '</h3>', 
  );
  $form['tutorial_remaining_monthly_credits'] = array(
    '#type' => 'item',
    '#title' => t('Remaining montly credits'), 
    '#value' => $ret->remaining_monthly_credits,
  );
  $form['tutorial_credits_per_month'] = array(
    '#type' => 'item',
    '#title' => t('Credits per month'), 
    '#value' => $ret->credits_per_month,
  );
  
  return system_settings_form($form);
}

/**
 * Tutorial listing page
 */

/**
 * Generates list of tutorials
 *  
 */
function tutorial_tutorial_list_page($path = '') {
  drupal_set_title('Tutorials');

  //$filter = tutorial_build_filter_query(); // not implemented yet
  if($path) {
    $path = str_replace(':', '/', $path);
  }
  if(isset($_GET['path']) && $_GET['path']) {
    $path = $_GET['path'];
  }
  if($path) {
    $filter =  tutorial_build_where_sql_from_path($path, '/', 'c');
    $options['path'] = 'path'; 
  }
  
  $rows = array();

//dsm($filter);
  $header = array(
    array('data' => t('Title'), 'field' => 't.title', 'sort' => 'asc'),
    array('data' => t('Teaser'), 'field' => 't.teaser'),
    array('data' => t('Operations')),
  );  
  $result = tutorial_load_filtered_tutorial_result($filter, $options, $header);

  $dest = 'admin/content/tutorial';
  while ($r = db_fetch_object($result)) {
    $rows[] = array('data' =>
      array(
        // Cells
        check_plain($r->title),
        check_plain($r->teaser),
        l(t('view'), 'admin/content/tutorial/tutorial_view/' . $r->tid, array('query' => 'destination=' . $dest)) . ' | ' .
        l(t('edit'), 'admin/content/tutorial/tutorial_edit/' . $r->tid, array('query' => 'destination=' . $dest)),
      ),
      // Attributes for tr
      'class' => "tutorial"
    );
  }

  if (!$rows) {
    $rows[] = array(array('data' => t('No tutorials were found.'), 'colspan' => count($header)));
  }

  $output .= l(t('Add tutorial'), 'admin/content/tutorial/tutorial/add', array('query' => 'destination=' . $dest));

  $output .= theme('table', $header, $rows, array('id' => 'tutorial-tutorials'));
  $output .= theme('pager', NULL, 100, 0);
  
  return $output;  
}

function tutorial_tutorial_page($tid = 0) {
	if(!$tid) {
		drupal_set_message(t('No tutorial id was specified. ' . l(t('Click here to see a list of tutorials.'), 'admin/content/tutorial/tutorial_list')), $type = 'error');
	  return '';
	}
	$tutorial = tutorial_load_tutorial($tid);
  drupal_set_title($tutorial->title);
  
  $output .= $tutorial->body;
  
  return $output;
}

function tutorial_tutorial_edit_page($tid) {
	return drupal_get_form('tutorial_tutorial_edit_form', $tid = 0);
}

function tutorial_tutorial_edit_form(&$form_state = array(), $tid = 0, $op = '') {
	$mode = 'add';
	if($tid && is_numeric($tid)) {
		$mode = 'edit';
		$tutorial = tutorial_load_tutorial($tid);
		$form['tutorial_tid'] = array(
      '#type' => 'value',
      '#value' => $tutorial->tid,
    );
    $form['tutorial_nid'] = array(
      '#type' => 'value',
      '#value' => $tutorial->nid,
    ); 
    $form['tutorial_video_source'] = array(
      '#type' => 'value',
      '#value' => $tutorial->video_source,
    ); 
    $form['tutorial_duration'] = array(
      '#type' => 'value',
      '#value' => $tutorial->duration,
    );
    $form['tutorial_published_date'] = array(
      '#type' => 'value',
      '#value' => $tutorial->published_date,
    );   
	}

  $form['title'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    //'#description' => t(''),
    '#default_value' => $tutorial->title,
    '#required' => TRUE,
  );
  
  $form['teaser'] = array(
    '#type' => 'textarea',
    '#title' => t('Teaser'),
    '#description' => t('A text summary of the tutorial.'),
    '#default_value' => $tutorial->teaser,
    '#rows' => 4,
  );
  
  $form['body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#description' => t('The tutorial content. For video tutorials, use the code to embed the video. For text tutorials input text and markup.'),
    '#default_value' => $tutorial->body,
    '#required' => TRUE,
    '#rows' => 10,
  );	
	
	$form = array_merge($form, tutorial_node_edit_fieldset($tid));
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
  );
  
	return $form;
}

function tutorial_tutorial_edit_form_submit($form, &$form_state) {
  $tutorial = new stdClass;
  $tutorial->tid = $form_state['values']['tutorial_tid'];
  $tutorial->type = 'tid'; 
  $tutorial->nid = $form_state['values']['tutorial_nid'];
  $tutorial->title = $form_state['values']['title'];
  $tutorial->teaser = $form_state['values']['teaser'];
  $tutorial->body = $form_state['values']['body'];
  $tutorial->video_source = $form_state['values']['tutorial_video_source'];
  $tutorial->duration = $form_state['values']['tutorial_duration'];     
  $tutorial->published_date = $form_state['values']['tutorial_published_date']; 
  $contexts = $form_state['values']['tutorial']['tutorial_contexts'];
  $tutorial->contexts = tutorial_contexts_text_to_obj($contexts);
  $dependencies = $form_state['values']['tutorial']['tutorial_dependencies'];
  $tutorial->dependencies = tutorial_dependencies_text_to_obj($dependencies);
  tutorial_save_tutorial($tutorial); 
}